# Table of Contents

- [jira-software-integration](<./jira-software-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Jira Marketplace App](<./Jira-Marketplace-App.md>)
  - [Benefits](<./Jira-Marketplace-App/Benefits.md>)
  - [Limitations](<./Jira-Marketplace-App/Limitations.md>)
  - [Prerequisites](<./Jira-Marketplace-App/Prerequisites.md>)
  - [Step 1: Install the SAP LeanIX for Jira App](<./Jira-Marketplace-App/Step-1-Install-the-SAP-LeanIX-for-Jira-App.md>)
  - [Step 2: Configure the SAP LeanIX for Jira App](<./Jira-Marketplace-App/Step-2-Configure-the-SAP-LeanIX-for-Jira-App.md>)
  - [Linking Jira Issues to SAP LeanIX Fact Sheets](<./Jira-Marketplace-App/Linking-Jira-Issues-to-SAP-LeanIX-Fact-Sheets.md>)
  - [Creating Synchronization Mappings](<./Jira-Marketplace-App/Creating-Synchronization-Mappings.md>)
  - [Syncing Jira Issues with SAP LeanIX Fact Sheets](<./Jira-Marketplace-App/Syncing-Jira-Issues-with-SAP-LeanIX-Fact-Sheets.md>)
  - [Viewing Issues on Fact Sheets](<./Jira-Marketplace-App/Viewing-Issues-on-Fact-Sheets.md>)
  - [Creating Fact Sheets in Jira](<./Jira-Marketplace-App/Creating-Fact-Sheets-in-Jira.md>)
  - [Searching for Fact Sheets in Jira Advanced Search Using JQL](<./Jira-Marketplace-App/Searching-for-Fact-Sheets-in-Jira-Advanced-Search-Using-JQL.md>)
  - [Was this page helpful?](<./Jira-Marketplace-App/Was-this-page-helpful.md>)
